package cn.itcast.hotel;

import cn.itcast.hotel.constants.HotelConstants;
import org.apache.http.HttpHost;
import org.elasticsearch.action.admin.indices.delete.DeleteIndexRequest;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestClient;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.client.indices.CreateIndexRequest;
import org.elasticsearch.client.indices.GetIndexRequest;
import org.elasticsearch.common.xcontent.XContentType;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;

public class HotelIndexTest {
    private RestHighLevelClient client;

    @BeforeEach
    void setup() throws Exception {
        this.client = new RestHighLevelClient(RestClient.builder((
                        HttpHost.create("http://192.168.1.4:9200"))
                // 集群缓环境下可以配置多个
                // HttpHost.create("http://192.168.1.7:9200")
        ));
    }

    @AfterEach
    void teardown() throws Exception {
        this.client.close();
    }

    // 初始化输出
    @Test
    void testInit() {
        System.out.println(client);
    }

    // 添加索引库
    @Test
    void createHotelIndex() throws IOException {
        // 1. 创建Request对象
        CreateIndexRequest request = new CreateIndexRequest("hotel");
        // 2.准备请求参数，DSL语句
        request.source(HotelConstants.HOTEL_JSON, XContentType.JSON);
        // 3. 发送请求
        client.indices().create(request, RequestOptions.DEFAULT);
    }

    // 删除索引库
    @Test
    void deleteHotelIndex() throws IOException {
        // 1. 创建Request对象
        DeleteIndexRequest request = new DeleteIndexRequest("hotel");
        // 2. 删除索引库
        client.indices().delete(request, RequestOptions.DEFAULT);
    }

    // 查询索引库
    @Test
    void getHotelIndex() throws IOException {
        // 1. 创建Request对象
        GetIndexRequest request = new GetIndexRequest("hotel");
        // 2. 查询索引库
        boolean exists = client.indices().exists(request, RequestOptions.DEFAULT);
        // 输出是否删除
        System.out.println(exists);
    }
}
